==> designer-common-1.0.10-20251126.022212-3-sources.jar: com/digiwin/athena/utils/operation/OperationTableNameConstants.java <==
package com.digiwin.athena.utils.operation;

/**
 * @author yueyyc
 * @version 1.0
 * @date 2023/3/8 15:18
 */
public class OperationTableNameConstants {

    // 应用表
    public static final String APPLICATION = "application";
    // 应用关系表
    public static final String APPLICATION_RELATION = "applicationRelation";
    // 参数定义表
    public static final String VARIABLE_DEFINITION = "variableDefinition";
    // 扩展信息表
    public static final String EXTEND_FIELD = "extendField";
    // 数据状态表
    public static final String DATA_STATE = "dataState";
    // 数据描述表
    public static final String DATA_DESCRIPTION = "dataDescription";
    // 数据描述表
    public static final String DATA_GROUP = "dataGroup";
    // 任务表
    public static final String TASK = "task";
    // 活动表
    public static final String ACTIVITY = "activity";
    // 活动表
    public static final String NEO4J_ACTIVITY = "neo4jActivity";
    // 流程图表
    public static final String FLOW_GRAPH = "flowGraph";
    // 项目表
    public static final String PROJECT = "project";
    // 机制定义表
    public static final String MECHANISM_DEFINITION = "mechanismDefinition";
    // 侦测规则表
    public static final String MONITOR_RULE = "monitorRule";

    public static final String PAGE_VIEW = "pageView";

    //表单设计
    public static final String PAGE_DESIGN = "pageDesign";
    public static final String PAGE_DSL = "pageDsl";

    //表单设计
    public static final String MOBILE_PAGE_DESIGN = "mobilePageDesign";

    //表单设计
    public static final String WORK_BENCH = "workbench";

    public static final String PAGE_DESIGN_MODEL = "pageDesignModel";

    public static final String DATA_VIEW = "dataView";

    public static final String EVENT_TEMPLATE = "eventTemplate";

    public static final String EVENT_SUBSCRIBE = "eventSubscribe";

    public static final String BUSINESS_DIR = "businessDir";

    public static final String KIT_ASSIGN = "kitAssign";

    public static final String AGILEDATA_DATA_FLOW = "agiledata_data_flow";

    public static final String AGILEDATA_SECTION_CONFIG = "agiledata_section_config";

    public static final String AGILEDATA_SCENE_TRIGGER = "agiledata_scene_trigger";

    /**
     *
     */
    public static final String AGILEDATAINQUIRY_DATA_SET = "agiledatainquiry_data_set";

    public static final String PAGE_UIELEMENT = "pageUIElement";


    // 模型和作业的关系
    public static final String PAGE_DESIGN_AND_MODEL = "pageDesignModelDslRelation";

    public static final String TASK_RELATION = "taskRelation";

    public static final String DATA_ENTRY_RELATION = "dataEntryRelation";

    public static final String STATEMENT_RELATION = "statementRelation";

    public static final String RULE = "rules";

    public static final String TAG = "Tag";
    // 服务编排模块表
    public static final String ADTEMPLATE = "adTemplate";
    // 应用参数表
    public static final String APPLICATION_PARAM = "applicationParam";
    //
    public static final String ACTION_METADATA = "actionMetadata";
    //
    public static final String TRANSFORM_ACTION_RULE = "transformActionRule";
    //
    public static final String ACTIVITY_CONFIGS = "activityConfigs";
    //
    public static final String ENTITY_RELATION_ANNOTATION = "entityRelationAnnotation";
    //
    public static final String MECHANISM_GROUP = "mechanismGroup";

    public static final String AD_TAG = "adTag";

    public static final String OPENWINDOW_DEFINITION = "openWindowDefinition";
    //
    public static final String ACTIVITY_VISIBLE_CONFIG = "activityVisibleConfig";
    /********************************公共应用的表*************************************/
    // 公共表的应用code直接写"common"
    public static final String COMMON_APP = "common";
    //
    public static final String ACTION_BINDING_TAG = "actionBindingTag";
    //
    public static final String DUTY = "duty";
    //
    public static final String ACTION_FIELD_RELATION = "actionFieldRelation";
    //
    public static final String TAG_DEFINITION = "tag-definition";
    //
    public static final String TM_WORD_CATEGORY = "tm_word_category";
    //
    public static final String TM_WORD_BEAN = "tm_word_bean";

    // 机制表
    public static final String mechanismLogic = "mechanismLogic";

    public static final String MECHANISM_PRINCIPLE = "principle";

    public static final String MECHANISM_PRINCIPLE_DETAIL = "principleDetail";

    public static final String COMPONENT_STRUCTURED_LIST = "componentStructuredList";

    public static final String MECHANISM = "mechanism";

    public static final String PARADIGM = "paradigm";

    public static final String MECHANISM_OUTPUT_TEMPLATE = "mechanismOutputTemplate";
    // 扩展配置表
    public static final String EXTEND_CONFIG = "extendConfig";

    public static final String PAGE_CARD = "pageCard";

    public static final String TASK_DETAIL = "taskDetail";

    public static final String PROJECT_DETAIL = "projectDetail";

    public static final String DICTIONARY = "dictionary";

    public static final String SVC_PARAM = "SvcParam";

    public static final String DATA_FEATURE_SET = "dataFeatureSet";

    public static final String DECISION = "decisionModel";
    // 分组表
    public static final String APPLICATION_GROUP = "applicationGroup";

    public static final String PROCESS = "process";
    /**
     * 场景
     */
    public static final String ASSISTANT_SCENE = "asa_assistantScene";

    public static final String APPLICATION_CUSTOMIZED_CONFIG = "applicationCustomizedConfig";
    public static final String SYS_APPLICATION_CUSTOMIZED_CONFIG = "sysApplicationCustomizedConfig";
    public static final String FAVOURITE = "favourite";

    public static final String ACTION_META_DATA = "actionMetadata";

    public static final String DELETE_API_META_DATA = "deleteApiMetaDataInfo";

    public static final String SUB_PAGE = "subPage";

    public static final String LCDP_PAGE_DESIGN = "lcdp_pageDesign";
}

==> designer-common-1.0.10-20251203.111911-19-sources.jar: com/digiwin/athena/utils/operation/OperationTableNameConstants.java <==
package com.digiwin.athena.utils.operation;

/**
 * @author yueyyc
 * @version 1.0
 * @date 2023/3/8 15:18
 */
public class OperationTableNameConstants {

    // 应用表
    public static final String APPLICATION = "application";
    // 应用关系表
    public static final String APPLICATION_RELATION = "applicationRelation";
    // 参数定义表
    public static final String VARIABLE_DEFINITION = "variableDefinition";
    // 扩展信息表
    public static final String EXTEND_FIELD = "extendField";
    // 数据状态表
    public static final String DATA_STATE = "dataState";
    // 数据描述表
    public static final String DATA_DESCRIPTION = "dataDescription";
    // 数据描述表
    public static final String DATA_GROUP = "dataGroup";
    // 任务表
    public static final String TASK = "task";
    // 活动表
    public static final String ACTIVITY = "activity";
    // 活动表
    public static final String NEO4J_ACTIVITY = "neo4jActivity";
    // 流程图表
    public static final String FLOW_GRAPH = "flowGraph";
    // 项目表
    public static final String PROJECT = "project";
    // 机制定义表
    public static final String MECHANISM_DEFINITION = "mechanismDefinition";
    // 侦测规则表
    public static final String MONITOR_RULE = "monitorRule";

    public static final String PAGE_VIEW = "pageView";

    //表单设计
    public static final String PAGE_DESIGN = "pageDesign";

    //表单设计
    public static final String MOBILE_PAGE_DESIGN = "mobilePageDesign";

    //表单设计
    public static final String WORK_BENCH = "workbench";

    public static final String PAGE_DESIGN_MODEL = "pageDesignModel";

    public static final String DATA_VIEW = "dataView";

    public static final String EVENT_TEMPLATE = "eventTemplate";

    public static final String EVENT_SUBSCRIBE = "eventSubscribe";

    public static final String BUSINESS_DIR = "businessDir";

    public static final String KIT_ASSIGN = "kitAssign";

    public static final String AGILEDATA_DATA_FLOW = "agiledata_data_flow";

    public static final String AGILEDATA_SECTION_CONFIG = "agiledata_section_config";

    public static final String AGILEDATA_SCENE_TRIGGER = "agiledata_scene_trigger";

    /**
     *
     */
    public static final String AGILEDATAINQUIRY_DATA_SET = "agiledatainquiry_data_set";
    public static final String AGILEDATAINQUIRY_IMPLICIT_ASSOCIATION = "agiledatainquiry_implicit_association";

    public static final String PAGE_UIELEMENT = "pageUIElement";


    // 模型和作业的关系
    public static final String PAGE_DESIGN_AND_MODEL = "pageDesignModelDslRelation";

    public static final String TASK_RELATION = "taskRelation";

    public static final String DATA_ENTRY_RELATION = "dataEntryRelation";

    public static final String STATEMENT_RELATION = "statementRelation";

    public static final String RULE = "rules";

    public static final String TAG = "Tag";
    // 服务编排模块表
    public static final String ADTEMPLATE = "adTemplate";
    // 应用参数表
    public static final String APPLICATION_PARAM = "applicationParam";
    //
    public static final String ACTION_METADATA = "actionMetadata";
    //
    public static final String TRANSFORM_ACTION_RULE = "transformActionRule";
    //
    public static final String ACTIVITY_CONFIGS = "activityConfigs";
    //
    public static final String ENTITY_RELATION_ANNOTATION = "entityRelationAnnotation";
    //
    public static final String MECHANISM_GROUP = "mechanismGroup";

    public static final String AD_TAG = "adTag";

    public static final String OPENWINDOW_DEFINITION = "openWindowDefinition";
    //
    public static final String ACTIVITY_VISIBLE_CONFIG = "activityVisibleConfig";
    /********************************公共应用的表*************************************/
    // 公共表的应用code直接写"common"
    public static final String COMMON_APP = "common";
    //
    public static final String ACTION_BINDING_TAG = "actionBindingTag";
    //
    public static final String DUTY = "duty";
    //
    public static final String ACTION_FIELD_RELATION = "actionFieldRelation";
    //
    public static final String TAG_DEFINITION = "tag-definition";
    //
    public static final String TM_WORD_CATEGORY = "tm_word_category";
    //
    public static final String TM_WORD_BEAN = "tm_word_bean";

    // 机制表
    public static final String mechanismLogic = "mechanismLogic";

    public static final String MECHANISM_PRINCIPLE = "principle";

    public static final String MECHANISM_PRINCIPLE_DETAIL = "principleDetail";

    public static final String COMPONENT_STRUCTURED_LIST = "componentStructuredList";

    public static final String MECHANISM = "mechanism";

    public static final String PARADIGM = "paradigm";

    public static final String MECHANISM_SETTINGS = "mechanismSettings";

    public static final String MECHANISM_OUTPUT_TEMPLATE = "mechanismOutputTemplate";
    // 扩展配置表
    public static final String EXTEND_CONFIG = "extendConfig";

    public static final String PAGE_CARD = "pageCard";

    public static final String TASK_DETAIL = "taskDetail";

    public static final String PROJECT_DETAIL = "projectDetail";

    public static final String DICTIONARY = "dictionary";

    public static final String SVC_PARAM = "SvcParam";

    public static final String DATA_FEATURE_SET = "dataFeatureSet";

    public static final String DECISION = "decisionModel";
    // 分组表
    public static final String APPLICATION_GROUP = "applicationGroup";

    public static final String PROCESS = "process";

    //参数设计器
    public static final String APP_PARAM = "appParam";

    /**
     * 场景
     */
    public static final String ASSISTANT_SCENE = "asa_assistantScene";

    public static final String APPLICATION_CUSTOMIZED_CONFIG = "applicationCustomizedConfig";
    public static final String SYS_APPLICATION_CUSTOMIZED_CONFIG = "sysApplicationCustomizedConfig";
    public static final String FAVOURITE = "favourite";

    public static final String ACTION_META_DATA = "actionMetadata";

    public static final String DELETE_API_META_DATA = "deleteApiMetaDataInfo";

    public static final String SUB_PAGE = "subPage";

    public static final String LCDP_PAGE_DESIGN = "lcdp_pageDesign";
}
